IpBits class

Constructors

IpBits(IpVersion version, Vt_as_string vt_as_compressed_string, Vt_as_string vt_as_uncompressed_string, int bits, int part_bits, int dns_bits, String rev_domain, BigInt part_mod, BigInt host_ofs)

Properties

bits int
getter/setter pair
dns_bits int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host_ofs BigInt
final
part_bits int
getter/setter pair
part_mod BigInt
final
rev_domain String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version IpVersion
final
vt_as_compressed_string Vt_as_string
final
vt_as_uncompressed_string Vt_as_string
final

Methods

as_compressed_string(BigInt bu) String
as_uncompressed_string(BigInt bu) String
dns_part_format(int i) String
Inspect() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parts(BigInt bu) List<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

V4 IpBits
final
V6 IpBits
final

Static Methods

reverse(List<int> data) List<int>
v4() IpBits
v6() IpBits