IpV4 class
Constructors
- IpV4()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
String str) → Result< IPAddress, String> -
from_u32(
int addr, int _prefix) → Result< IPAddress, String> -
ipv4_is_loopback(
IPAddress my) → bool -
ipv4_is_private(
IPAddress my) → bool -
is_class_a(
IPAddress my) → bool -
is_class_b(
IPAddress my) → bool -
is_class_c(
IPAddress my) → bool -
parse_classful(
String ip_s) → Result< IPAddress, String> -
to_ipv6(
IPAddress ia) → IPAddress