IpV6 class

Constructors

IpV6()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

ipv6_is_loopback VtBool
final
ipv6_is_private VtBool
final
ipv6_to_ipv6 VtIPAddress
=Name
final

Static Methods

create(String str) → Result<IPAddress, String>
Creates a IPv6 address object.
enhance_if_mapped(IPAddress ip) → Result<IPAddress, String>
from_int(BigInt bi, int prefixNum) → Result<IPAddress, String>
from_str(String str, int radix, int prefix) → Result<IPAddress, String>