Prefix32 class

Constructors

Prefix32()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

from(Prefix my, int num) → Result<Prefix, String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(int num) → Result<Prefix, String>
Gives the prefix in IPv4 dotted decimal format, i.e. the canonical netmask we're all used to