Last class

Constructors

Last()

Properties

hashCode int
The hash code for this object.
no setterinherited
max_poses Map<int, List<int>>
final
ret List<Rle>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Rle?
getter/setter pair

Methods

handle_last() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited