Rle class

Constructors

Rle(int part, int pos, int cnt, bool max)

Properties

cnt int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
max bool
getter/setter pair
part int
getter/setter pair
pos int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eq(Rle other) bool
Inspect() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

code(List<int> parts) List<Rle>