Prefix class
Properties
Methods
-
add(
int other) → Result< Prefix, String> -
add_prefix(
Prefix other) → Result< Prefix, String> -
bits(
) → String - Transforms the prefix into a string of bits representing the netmask
-
clone(
) → Prefix -
compare(
Prefix oth) → int -
equal(
Prefix other) → bool -
from(
int num) → Result< Prefix, String> -
get_prefix(
) → int -
host_mask(
) → BigInt - The hostmask is the contrary of the subnet mask, as it shows the bits that can change within the hosts
-
host_prefix(
) → int - Returns the length of the host portion of a netmask.
-
inspect(
) → String -
netmask(
) → BigInt -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
size(
) → BigInt -
sub(
int other) → Result< Prefix, String> -
sub_prefix(
Prefix other) → Result< Prefix, String> -
to_i(
) → int -
to_ip_str(
) → String -
to_s(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
new_netmask(
int prefix, int bits) → BigInt